@@ -25,11 +25,12 @@ import (
 	"github.com/spf13/cobra"
 	"k8s.io/apimachinery/pkg/api/resource"
 	"k8s.io/cli-runtime/pkg/genericclioptions"
+	"knative.dev/serving/pkg/apis/serving"
+	servingv1 "knative.dev/serving/pkg/apis/serving/v1"
+
 	"knative.dev/client/pkg/kn/commands"
 	"knative.dev/client/pkg/printers"
 	clientserving "knative.dev/client/pkg/serving"
-	servingserving "knative.dev/serving/pkg/apis/serving"
-	"knative.dev/serving/pkg/apis/serving/v1alpha1"
 )
 
 // Matching image digest
@@ -42,12 +43,11 @@ func NewRevisionDescribeCommand(p *commands.KnParams) *cobra.Command {
 
 	command := &cobra.Command{
 		Use:   "describe NAME",
-		Short: "Describe revisions.",
+		Short: "Show details of a revision",
 		RunE: func(cmd *cobra.Command, args []string) error {
-			if len(args) < 1 {
-				return errors.New("requires the revision name.")
+			if len(args) != 1 {
+				return errors.New("'kn revision describe' requires name of the revision as single argument")
 			}
-
 			namespace, err := p.GetNamespace(cmd)
 			if err != nil {
 				return err
@@ -73,8 +73,8 @@ func NewRevisionDescribeCommand(p *commands.KnParams) *cobra.Command {
 			if err != nil {
 				return err
 			}
-			var service *v1alpha1.Service
-			serviceName, ok := revision.Labels[servingserving.ServiceLabelKey]
+			var service *servingv1.Service
+			serviceName, ok := revision.Labels[serving.ServiceLabelKey]
 			if printDetails && ok {
 				service, err = client.GetService(serviceName)
 				if err != nil {
@@ -92,20 +92,21 @@ func NewRevisionDescribeCommand(p *commands.KnParams) *cobra.Command {
 	return command
 }
 
-func describe(w io.Writer, revision *v1alpha1.Revision, service *v1alpha1.Service, printDetails bool) error {
+func describe(w io.Writer, revision *servingv1.Revision, service *servingv1.Service, printDetails bool) error {
 	dw := printers.NewPrefixWriter(w)
 	commands.WriteMetadata(dw, &revision.ObjectMeta, printDetails)
 	WriteImage(dw, revision)
 	WritePort(dw, revision)
 	WriteEnv(dw, revision, printDetails)
+	WriteEnvFrom(dw, revision, printDetails)
 	WriteScale(dw, revision)
 	WriteConcurrencyOptions(dw, revision)
 	WriteResources(dw, revision)
-	serviceName, ok := revision.Labels[servingserving.ServiceLabelKey]
+	serviceName, ok := revision.Labels[serving.ServiceLabelKey]
 	if ok {
 		serviceSection := dw.WriteAttribute("Service", serviceName)
 		if printDetails {
-			serviceSection.WriteAttribute("Configuration Generation", revision.Labels[servingserving.ConfigurationGenerationLabelKey])
+			serviceSection.WriteAttribute("Configuration Generation", revision.Labels[serving.ConfigurationGenerationLabelKey])
 			serviceSection.WriteAttribute("Latest Created", strconv.FormatBool(revision.Name == service.Status.LatestCreatedRevisionName))
 			serviceSection.WriteAttribute("Latest Ready", strconv.FormatBool(revision.Name == service.Status.LatestReadyRevisionName))
 			percent, tags := trafficAndTagsForRevision(revision.Name, service)
@@ -126,7 +127,7 @@ func describe(w io.Writer, revision *v1alpha1.Revision, service *v1alpha1.Servic
 	return nil
 }
 
-func WriteConcurrencyOptions(dw printers.PrefixWriter, revision *v1alpha1.Revision) {
+func WriteConcurrencyOptions(dw printers.PrefixWriter, revision *servingv1.Revision) {
 	target := clientserving.ConcurrencyTarget(&revision.ObjectMeta)
 	limit := revision.Spec.ContainerConcurrency
 	autoscaleWindow := clientserving.AutoscaleWindow(&revision.ObjectMeta)
@@ -146,7 +147,7 @@ func WriteConcurrencyOptions(dw printers.PrefixWriter, revision *v1alpha1.Revisi
 }
 
 // Write the image attribute (with
-func WriteImage(dw printers.PrefixWriter, revision *v1alpha1.Revision) {
+func WriteImage(dw printers.PrefixWriter, revision *servingv1.Revision) {
 	c, err := clientserving.ContainerOfRevisionSpec(&revision.Spec)
 	if err != nil {
 		dw.WriteAttribute("Image", "Unknown")
@@ -176,21 +177,28 @@ func WriteImage(dw printers.PrefixWriter, revision *v1alpha1.Revision) {
 	dw.WriteAttribute("Image", image)
 }
 
-func WritePort(dw printers.PrefixWriter, revision *v1alpha1.Revision) {
+func WritePort(dw printers.PrefixWriter, revision *servingv1.Revision) {
 	port := clientserving.Port(&revision.Spec)
 	if port != nil {
 		dw.WriteAttribute("Port", strconv.FormatInt(int64(*port), 10))
 	}
 }
 
-func WriteEnv(dw printers.PrefixWriter, revision *v1alpha1.Revision, printDetails bool) {
+func WriteEnv(dw printers.PrefixWriter, revision *servingv1.Revision, printDetails bool) {
 	env := stringifyEnv(revision)
 	if env != nil {
 		commands.WriteSliceDesc(dw, env, "Env", printDetails)
 	}
 }
 
-func WriteScale(dw printers.PrefixWriter, revision *v1alpha1.Revision) {
+func WriteEnvFrom(dw printers.PrefixWriter, revision *servingv1.Revision, printDetails bool) {
+	envFrom := stringifyEnvFrom(revision)
+	if envFrom != nil {
+		commands.WriteSliceDesc(dw, envFrom, "EnvFrom", printDetails)
+	}
+}
+
+func WriteScale(dw printers.PrefixWriter, revision *servingv1.Revision) {
 	// Scale spec if given
 	scale, err := clientserving.ScalingInfo(&revision.ObjectMeta)
 	if err != nil {
@@ -201,7 +209,7 @@ func WriteScale(dw printers.PrefixWriter, revision *v1alpha1.Revision) {
 	}
 }
 
-func WriteResources(dw printers.PrefixWriter, r *v1alpha1.Revision) {
+func WriteResources(dw printers.PrefixWriter, r *servingv1.Revision) {
 	c, err := clientserving.ContainerOfRevisionSpec(&r.Spec)
 	if err != nil {
 		return
@@ -258,7 +266,7 @@ func formatScale(minScale *int, maxScale *int) string {
 	return ret
 }
 
-func stringifyEnv(revision *v1alpha1.Revision) []string {
+func stringifyEnv(revision *servingv1.Revision) []string {
 	container, err := clientserving.ContainerOfRevisionSpec(&revision.Spec)
 	if err != nil {
 		return nil
@@ -274,3 +282,21 @@ func stringifyEnv(revision *v1alpha1.Revision) []string {
 	}
 	return envVars
 }
+
+func stringifyEnvFrom(revision *servingv1.Revision) []string {
+	container, err := clientserving.ContainerOfRevisionSpec(&revision.Spec)
+	if err != nil {
+		return nil
+	}
+
+	var result []string
+	for _, envFromSource := range container.EnvFrom {
+		if envFromSource.ConfigMapRef != nil {
+			result = append(result, "cm:"+envFromSource.ConfigMapRef.Name)
+		}
+		if envFromSource.SecretRef != nil {
+			result = append(result, "secret:"+envFromSource.SecretRef.Name)
+		}
+	}
+	return result
+}
