@@ -23,17 +23,18 @@ import (
 
 	"k8s.io/apimachinery/pkg/util/sets"
 	"k8s.io/cli-runtime/pkg/genericclioptions"
+	"knative.dev/serving/pkg/apis/serving"
+
 	"knative.dev/client/pkg/kn/commands/revision"
 	"knative.dev/client/pkg/printers"
-	serving_kn_v1alpha1 "knative.dev/client/pkg/serving/v1alpha1"
-	"knative.dev/serving/pkg/apis/serving"
+	clientservingv1 "knative.dev/client/pkg/serving/v1"
 
 	"github.com/spf13/cobra"
 	corev1 "k8s.io/api/core/v1"
-	v1 "k8s.io/api/core/v1"
-	"knative.dev/client/pkg/kn/commands"
 	"knative.dev/pkg/apis"
-	"knative.dev/serving/pkg/apis/serving/v1alpha1"
+	servingv1 "knative.dev/serving/pkg/apis/serving/v1"
+
+	"knative.dev/client/pkg/kn/commands"
 )
 
 // Command for printing out a description of a service, meant to be consumed by humans
@@ -47,7 +48,7 @@ var printDetails bool
 // of a Service. These are plain data types which can be directly used
 // for printing out
 type revisionDesc struct {
-	revision *v1alpha1.Revision
+	revision *servingv1.Revision
 
 	// traffic stuff
 	percent       int64
@@ -77,13 +78,10 @@ func NewServiceDescribeCommand(p *commands.KnParams) *cobra.Command {
 
 	command := &cobra.Command{
 		Use:   "describe NAME",
-		Short: "Show details for a given service",
+		Short: "Show details of a service",
 		RunE: func(cmd *cobra.Command, args []string) error {
-			if len(args) < 1 {
-				return errors.New("no service name provided")
-			}
-			if len(args) > 1 {
-				return errors.New("more than one service name provided")
+			if len(args) != 1 {
+				return errors.New("'kn service describe' requires name of the service as single argument")
 			}
 			serviceName := args[0]
 
@@ -132,7 +130,7 @@ func NewServiceDescribeCommand(p *commands.KnParams) *cobra.Command {
 }
 
 // Main action describing the service
-func describe(w io.Writer, service *v1alpha1.Service, revisions []*revisionDesc, printDetails bool) error {
+func describe(w io.Writer, service *servingv1.Service, revisions []*revisionDesc, printDetails bool) error {
 	dw := printers.NewPrefixWriter(w)
 
 	// Service info
@@ -159,25 +157,25 @@ func describe(w io.Writer, service *v1alpha1.Service, revisions []*revisionDesc,
 }
 
 // Write out main service information. Use colors for major items.
-func writeService(dw printers.PrefixWriter, service *v1alpha1.Service) {
+func writeService(dw printers.PrefixWriter, service *servingv1.Service) {
 	commands.WriteMetadata(dw, &service.ObjectMeta, printDetails)
 	dw.WriteAttribute("URL", extractURL(service))
 	if printDetails {
 		if service.Status.Address != nil {
-			url := service.Status.Address.GetURL()
+			url := service.Status.Address.URL
 			dw.WriteAttribute("Cluster", url.String())
 		}
 	}
-	if (service.Spec.Template != nil) && (service.Spec.Template.Spec.ServiceAccountName != "") {
+	if service.Spec.Template.Spec.ServiceAccountName != "" {
 		dw.WriteAttribute("Service Account", service.Spec.Template.Spec.ServiceAccountName)
 	}
-	if service.Spec.Template != nil && service.Spec.Template.Spec.ImagePullSecrets != nil {
+	if service.Spec.Template.Spec.ImagePullSecrets != nil {
 		dw.WriteAttribute("Image Pull Secret", service.Spec.Template.Spec.ImagePullSecrets[0].Name)
 	}
 }
 
 // Write out revisions associated with this service. By default only active
-// target revisions are printed, but with --all also inactive revisions
+// target revisions are printed, but with --verbose also inactive revisions
 // created by this services are shown
 func writeRevisions(dw printers.PrefixWriter, revisions []*revisionDesc, printDetails bool) {
 	revSection := dw.WriteAttribute("Revisions", "")
@@ -185,7 +183,7 @@ func writeRevisions(dw printers.PrefixWriter, revisions []*revisionDesc, printDe
 	for _, revisionDesc := range revisions {
 		ready := apis.Condition{
 			Type:   apis.ConditionReady,
-			Status: v1.ConditionUnknown,
+			Status: corev1.ConditionUnknown,
 		}
 		for _, cond := range revisionDesc.revision.Status.Conditions {
 			if cond.Type == apis.ConditionReady {
@@ -194,13 +192,14 @@ func writeRevisions(dw printers.PrefixWriter, revisions []*revisionDesc, printDe
 			}
 		}
 		section := revSection.WriteColsLn(formatBullet(revisionDesc.percent, ready.Status), revisionHeader(revisionDesc))
-		if ready.Status == v1.ConditionFalse {
+		if ready.Status == corev1.ConditionFalse {
 			section.WriteAttribute("Error", ready.Reason)
 		}
 		revision.WriteImage(section, revisionDesc.revision)
 		if printDetails {
 			revision.WritePort(section, revisionDesc.revision)
 			revision.WriteEnv(section, revisionDesc.revision, printDetails)
+			revision.WriteEnvFrom(section, revisionDesc.revision, printDetails)
 			revision.WriteScale(section, revisionDesc.revision)
 			revision.WriteConcurrencyOptions(section, revisionDesc.revision)
 			revision.WriteResources(section, revisionDesc.revision)
@@ -239,11 +238,11 @@ func revisionHeader(desc *revisionDesc) string {
 func formatBullet(percentage int64, status corev1.ConditionStatus) string {
 	symbol := "+"
 	switch status {
-	case v1.ConditionTrue:
+	case corev1.ConditionTrue:
 		if percentage > 0 {
 			symbol = "%"
 		}
-	case v1.ConditionFalse:
+	case corev1.ConditionFalse:
 		symbol = "!"
 	default:
 		symbol = "?"
@@ -256,7 +255,7 @@ func formatBullet(percentage int64, status corev1.ConditionStatus) string {
 
 // Call the backend to query revisions for the given service and build up
 // the view objects used for output
-func getRevisionDescriptions(client serving_kn_v1alpha1.KnServingClient, service *v1alpha1.Service, withDetails bool) ([]*revisionDesc, error) {
+func getRevisionDescriptions(client clientservingv1.KnServingClient, service *servingv1.Service, withDetails bool) ([]*revisionDesc, error) {
 	revisionsSeen := sets.NewString()
 	revisionDescs := []*revisionDesc{}
 
@@ -293,7 +292,7 @@ func orderByConfigurationGeneration(descs []*revisionDesc) []*revisionDesc {
 	return descs
 }
 
-func completeWithLatestRevisions(client serving_kn_v1alpha1.KnServingClient, service *v1alpha1.Service, revisionsSeen sets.String, descs []*revisionDesc) ([]*revisionDesc, error) {
+func completeWithLatestRevisions(client clientservingv1.KnServingClient, service *servingv1.Service, revisionsSeen sets.String, descs []*revisionDesc) ([]*revisionDesc, error) {
 	for _, revisionName := range []string{service.Status.LatestCreatedRevisionName, service.Status.LatestReadyRevisionName} {
 		if revisionsSeen.Has(revisionName) {
 			continue
@@ -312,8 +311,8 @@ func completeWithLatestRevisions(client serving_kn_v1alpha1.KnServingClient, ser
 	return descs, nil
 }
 
-func completeWithUntargetedRevisions(client serving_kn_v1alpha1.KnServingClient, service *v1alpha1.Service, revisionsSeen sets.String, descs []*revisionDesc) ([]*revisionDesc, error) {
-	revisions, err := client.ListRevisions(serving_kn_v1alpha1.WithService(service.Name))
+func completeWithUntargetedRevisions(client clientservingv1.KnServingClient, service *servingv1.Service, revisionsSeen sets.String, descs []*revisionDesc) ([]*revisionDesc, error) {
+	revisions, err := client.ListRevisions(clientservingv1.WithService(service.Name))
 	if err != nil {
 		return nil, err
 	}
@@ -332,7 +331,7 @@ func completeWithUntargetedRevisions(client serving_kn_v1alpha1.KnServingClient,
 	return descs, nil
 }
 
-func newRevisionDesc(revision *v1alpha1.Revision, target *v1alpha1.TrafficTarget, service *v1alpha1.Service) (*revisionDesc, error) {
+func newRevisionDesc(revision *servingv1.Revision, target *servingv1.TrafficTarget, service *servingv1.Service) (*revisionDesc, error) {
 	generation, err := strconv.ParseInt(revision.Labels[serving.ConfigurationGenerationLabelKey], 0, 0)
 	if err != nil {
 		return nil, fmt.Errorf("cannot extract configuration generation for revision %s: %v", revision.Name, err)
@@ -351,7 +350,7 @@ func newRevisionDesc(revision *v1alpha1.Revision, target *v1alpha1.TrafficTarget
 	return &revisionDesc, nil
 }
 
-func addTargetInfo(desc *revisionDesc, target *v1alpha1.TrafficTarget) {
+func addTargetInfo(desc *revisionDesc, target *servingv1.TrafficTarget) {
 	if target != nil {
 		if target.Percent != nil {
 			desc.percent = *target.Percent
@@ -361,7 +360,7 @@ func addTargetInfo(desc *revisionDesc, target *v1alpha1.TrafficTarget) {
 	}
 }
 
-func extractRevisionFromTarget(client serving_kn_v1alpha1.KnServingClient, target v1alpha1.TrafficTarget) (*v1alpha1.Revision, error) {
+func extractRevisionFromTarget(client clientservingv1.KnServingClient, target servingv1.TrafficTarget) (*servingv1.Revision, error) {
 	var revisionName = target.RevisionName
 	if revisionName == "" {
 		configurationName := target.ConfigurationName
@@ -377,10 +376,6 @@ func extractRevisionFromTarget(client serving_kn_v1alpha1.KnServingClient, targe
 	return client.GetRevision(revisionName)
 }
 
-func extractURL(service *v1alpha1.Service) string {
-	status := service.Status
-	if status.URL != nil {
-		return status.URL.String()
-	}
-	return status.DeprecatedDomain
+func extractURL(service *servingv1.Service) string {
+	return service.Status.URL.String()
 }
