@@ -30,7 +30,7 @@ import (
 	"knative.dev/pkg/ptr"
 	"knative.dev/serving/pkg/apis/autoscaling"
 	"knative.dev/serving/pkg/apis/serving"
-	servingv1alpha1 "knative.dev/serving/pkg/apis/serving/v1alpha1"
+	servingv1 "knative.dev/serving/pkg/apis/serving/v1"
 )
 
 // VolumeSourceType is a type standing for enumeration of ConfigMap and Secret
@@ -55,7 +55,7 @@ var UserImageAnnotationKey = "client.knative.dev/user-image"
 // UpdateEnvVars gives the configuration all the env var values listed in the given map of
 // vars.  Does not touch any environment variables not mentioned, but it can add
 // new env vars and change the values of existing ones, then sort by env key name.
-func UpdateEnvVars(template *servingv1alpha1.RevisionTemplateSpec, toUpdate map[string]string, toRemove []string) error {
+func UpdateEnvVars(template *servingv1.RevisionTemplateSpec, toUpdate map[string]string, toRemove []string) error {
 	container, err := ContainerOfRevisionTemplate(template)
 	if err != nil {
 		return err
@@ -72,7 +72,7 @@ func UpdateEnvVars(template *servingv1alpha1.RevisionTemplateSpec, toUpdate map[
 }
 
 // UpdateEnvFrom updates envFrom
-func UpdateEnvFrom(template *servingv1alpha1.RevisionTemplateSpec, toUpdate []string, toRemove []string) error {
+func UpdateEnvFrom(template *servingv1.RevisionTemplateSpec, toUpdate []string, toRemove []string) error {
 	container, err := ContainerOfRevisionTemplate(template)
 	if err != nil {
 		return err
@@ -144,7 +144,7 @@ func reviseVolumesToRemove(volumeMounts []corev1.VolumeMount, volumesToRemove []
 }
 
 // UpdateVolumeMountsAndVolumes updates the configuration for volume mounts and volumes.
-func UpdateVolumeMountsAndVolumes(template *servingv1alpha1.RevisionTemplateSpec,
+func UpdateVolumeMountsAndVolumes(template *servingv1.RevisionTemplateSpec,
 	mountsToUpdate *util.OrderedMap, mountsToRemove []string, volumesToUpdate *util.OrderedMap, volumesToRemove []string) error {
 	container, err := ContainerOfRevisionTemplate(template)
 	if err != nil {
@@ -175,17 +175,17 @@ func UpdateVolumeMountsAndVolumes(template *servingv1alpha1.RevisionTemplateSpec
 }
 
 // UpdateMinScale updates min scale annotation
-func UpdateMinScale(template *servingv1alpha1.RevisionTemplateSpec, min int) error {
+func UpdateMinScale(template *servingv1.RevisionTemplateSpec, min int) error {
 	return UpdateRevisionTemplateAnnotation(template, autoscaling.MinScaleAnnotationKey, strconv.Itoa(min))
 }
 
 // UpdateMaxScale updates max scale annotation
-func UpdateMaxScale(template *servingv1alpha1.RevisionTemplateSpec, max int) error {
+func UpdateMaxScale(template *servingv1.RevisionTemplateSpec, max int) error {
 	return UpdateRevisionTemplateAnnotation(template, autoscaling.MaxScaleAnnotationKey, strconv.Itoa(max))
 }
 
 // UpdateAutoscaleWindow updates the autoscale window annotation
-func UpdateAutoscaleWindow(template *servingv1alpha1.RevisionTemplateSpec, window string) error {
+func UpdateAutoscaleWindow(template *servingv1.RevisionTemplateSpec, window string) error {
 	_, err := time.ParseDuration(window)
 	if err != nil {
 		return fmt.Errorf("invalid duration for 'autoscale-window': %v", err)
@@ -194,12 +194,12 @@ func UpdateAutoscaleWindow(template *servingv1alpha1.RevisionTemplateSpec, windo
 }
 
 // UpdateConcurrencyTarget updates container concurrency annotation
-func UpdateConcurrencyTarget(template *servingv1alpha1.RevisionTemplateSpec, target int) error {
+func UpdateConcurrencyTarget(template *servingv1.RevisionTemplateSpec, target int) error {
 	return UpdateRevisionTemplateAnnotation(template, autoscaling.TargetAnnotationKey, strconv.Itoa(target))
 }
 
 // UpdateConcurrencyLimit updates container concurrency limit
-func UpdateConcurrencyLimit(template *servingv1alpha1.RevisionTemplateSpec, limit int64) error {
+func UpdateConcurrencyLimit(template *servingv1.RevisionTemplateSpec, limit int64) error {
 	err := serving.ValidateContainerConcurrency(ptr.Int64(limit)).ViaField("spec.containerConcurrency")
 	if err != nil {
 		return fmt.Errorf("invalid 'concurrency-limit' value: %s", err)
@@ -211,7 +211,7 @@ func UpdateConcurrencyLimit(template *servingv1alpha1.RevisionTemplateSpec, limi
 
 // UpdateRevisionTemplateAnnotation updates an annotation for the given Revision Template.
 // Also validates the autoscaling annotation values
-func UpdateRevisionTemplateAnnotation(template *servingv1alpha1.RevisionTemplateSpec, annotation string, value string) error {
+func UpdateRevisionTemplateAnnotation(template *servingv1.RevisionTemplateSpec, annotation string, value string) error {
 	annoMap := template.Annotations
 	if annoMap == nil {
 		annoMap = make(map[string]string)
@@ -232,15 +232,6 @@ func UpdateRevisionTemplateAnnotation(template *servingv1alpha1.RevisionTemplate
 
 var ApiTooOldError = errors.New("the service is using too old of an API format for the operation")
 
-// UpdateName updates the revision name.
-func UpdateName(template *servingv1alpha1.RevisionTemplateSpec, name string) error {
-	if template.Spec.DeprecatedContainer != nil {
-		return ApiTooOldError
-	}
-	template.Name = name
-	return nil
-}
-
 // EnvToMap is an utility function to translate between the API list form of env vars, and the
 // more convenient map form.
 func EnvToMap(vars []corev1.EnvVar) (map[string]string, error) {
@@ -256,7 +247,7 @@ func EnvToMap(vars []corev1.EnvVar) (map[string]string, error) {
 }
 
 // UpdateImage a given image
-func UpdateImage(template *servingv1alpha1.RevisionTemplateSpec, image string) error {
+func UpdateImage(template *servingv1.RevisionTemplateSpec, image string) error {
 	// When not setting the image to a digest, add the user image annotation.
 	container, err := ContainerOfRevisionTemplate(template)
 	if err != nil {
@@ -267,12 +258,12 @@ func UpdateImage(template *servingv1alpha1.RevisionTemplateSpec, image string) e
 }
 
 // UnsetUserImageAnnot removes the user image annotation
-func UnsetUserImageAnnot(template *servingv1alpha1.RevisionTemplateSpec) {
+func UnsetUserImageAnnot(template *servingv1.RevisionTemplateSpec) {
 	delete(template.Annotations, UserImageAnnotationKey)
 }
 
 // SetUserImageAnnot sets the user image annotation if the image isn't by-digest already.
-func SetUserImageAnnot(template *servingv1alpha1.RevisionTemplateSpec) {
+func SetUserImageAnnot(template *servingv1.RevisionTemplateSpec) {
 	// If the current image isn't by-digest, set the user-image annotation to it
 	// so we remember what it was.
 	currentContainer, _ := ContainerOfRevisionTemplate(template)
@@ -290,7 +281,7 @@ func SetUserImageAnnot(template *servingv1alpha1.RevisionTemplateSpec) {
 }
 
 // FreezeImageToDigest sets the image on the template to the image digest of the base revision.
-func FreezeImageToDigest(template *servingv1alpha1.RevisionTemplateSpec, baseRevision *servingv1alpha1.Revision) error {
+func FreezeImageToDigest(template *servingv1.RevisionTemplateSpec, baseRevision *servingv1.Revision) error {
 	if baseRevision == nil {
 		return nil
 	}
@@ -314,8 +305,28 @@ func FreezeImageToDigest(template *servingv1alpha1.RevisionTemplateSpec, baseRev
 	return nil
 }
 
+// UpdateContainerCommand updates container with a given argument
+func UpdateContainerCommand(template *servingv1.RevisionTemplateSpec, command string) error {
+	container, err := ContainerOfRevisionTemplate(template)
+	if err != nil {
+		return err
+	}
+	container.Command = []string{command}
+	return nil
+}
+
+// UpdateContainerArg updates container with a given argument
+func UpdateContainerArg(template *servingv1.RevisionTemplateSpec, arg []string) error {
+	container, err := ContainerOfRevisionTemplate(template)
+	if err != nil {
+		return err
+	}
+	container.Args = arg
+	return nil
+}
+
 // UpdateContainerPort updates container with a give port
-func UpdateContainerPort(template *servingv1alpha1.RevisionTemplateSpec, port int32) error {
+func UpdateContainerPort(template *servingv1.RevisionTemplateSpec, port int32) error {
 	container, err := ContainerOfRevisionTemplate(template)
 	if err != nil {
 		return err
@@ -326,8 +337,20 @@ func UpdateContainerPort(template *servingv1alpha1.RevisionTemplateSpec, port in
 	return nil
 }
 
+// UpdateRunAsUser updates container with a given user id
+func UpdateUser(template *servingv1.RevisionTemplateSpec, user int64) error {
+	container, err := ContainerOfRevisionTemplate(template)
+	if err != nil {
+		return err
+	}
+	container.SecurityContext = &corev1.SecurityContext{
+		RunAsUser: &user,
+	}
+	return nil
+}
+
 // UpdateResources updates resources as requested
-func UpdateResources(template *servingv1alpha1.RevisionTemplateSpec, requestsResourceList corev1.ResourceList, limitsResourceList corev1.ResourceList) error {
+func UpdateResources(template *servingv1.RevisionTemplateSpec, requestsResourceList corev1.ResourceList, limitsResourceList corev1.ResourceList) error {
 	container, err := ContainerOfRevisionTemplate(template)
 	if err != nil {
 		return err
@@ -351,31 +374,27 @@ func UpdateResources(template *servingv1alpha1.RevisionTemplateSpec, requestsRes
 	return nil
 }
 
-// UpdateLabels updates the labels identically on a service and template.
-// Does not overwrite the entire Labels field, only makes the requested updates
-func UpdateLabels(service *servingv1alpha1.Service, template *servingv1alpha1.RevisionTemplateSpec, toUpdate map[string]string, toRemove []string) error {
-	if service.ObjectMeta.Labels == nil {
-		service.ObjectMeta.Labels = make(map[string]string)
+// UpdateLabels updates the labels by adding items from `add` then removing any items from `remove`
+func UpdateLabels(labelsMap map[string]string, add map[string]string, remove []string) map[string]string {
+	if labelsMap == nil {
+		labelsMap = map[string]string{}
 	}
-	if template.ObjectMeta.Labels == nil {
-		template.ObjectMeta.Labels = make(map[string]string)
+
+	for key, value := range add {
+		labelsMap[key] = value
 	}
-	for key, value := range toUpdate {
-		service.ObjectMeta.Labels[key] = value
-		template.ObjectMeta.Labels[key] = value
+	for _, key := range remove {
+		delete(labelsMap, key)
 	}
-	for _, key := range toRemove {
-		delete(service.ObjectMeta.Labels, key)
-		delete(template.ObjectMeta.Labels, key)
-	}
-	return nil
+
+	return labelsMap
 }
 
 // UpdateAnnotations updates the annotations identically on a service and template.
 // Does not overwrite the entire Annotations field, only makes the requested updates.
 func UpdateAnnotations(
-	service *servingv1alpha1.Service,
-	template *servingv1alpha1.RevisionTemplateSpec,
+	service *servingv1.Service,
+	template *servingv1.RevisionTemplateSpec,
 	toUpdate map[string]string,
 	toRemove []string) error {
 
@@ -401,14 +420,14 @@ func UpdateAnnotations(
 }
 
 // UpdateServiceAccountName updates the service account name used for the corresponding knative service
-func UpdateServiceAccountName(template *servingv1alpha1.RevisionTemplateSpec, serviceAccountName string) error {
+func UpdateServiceAccountName(template *servingv1.RevisionTemplateSpec, serviceAccountName string) error {
 	serviceAccountName = strings.TrimSpace(serviceAccountName)
 	template.Spec.ServiceAccountName = serviceAccountName
 	return nil
 }
 
 // UpdateImagePullSecrets updates the image pull secrets used for the corresponding knative service
-func UpdateImagePullSecrets(template *servingv1alpha1.RevisionTemplateSpec, pullsecrets string) {
+func UpdateImagePullSecrets(template *servingv1.RevisionTemplateSpec, pullsecrets string) {
 	pullsecrets = strings.TrimSpace(pullsecrets)
 	if pullsecrets == "" {
 		template.Spec.ImagePullSecrets = nil
